# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ApimodelsCreateTagReq
from ..models import ApimodelsCreateTagResp
from ..models import ApimodelsErrorResponse
from ..models import ApimodelsListTagsResp

from ..operations.admin_tags import AdminCreateTag
from ..operations.admin_tags import AdminDeleteTag
from ..operations.admin_tags import AdminListTags
from ..operations.admin_tags import (
    AdminListTagsSortByEnum,
)
from ..models import ApimodelsCreateTagReqOwnerEnum
from ..models import ApimodelsCreateTagRespOwnerEnum


@same_doc_as(AdminCreateTag)
def admin_create_tag(
    body: ApimodelsCreateTagReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """To create a tag (AdminCreateTag)

    This endpoint will create a new tag.
    The tag name must be unique per namespace.
    It is safe to call this endpoint even if the tag already exists.

    Permission: ADMIN:NAMESPACE:{namespace}:INVENTORY:TAG [CREATE]

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/tags

        method: POST

        tags: ["Admin Tags"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelsCreateTagReq in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApimodelsCreateTagResp (Created)

        400: Bad Request - ApimodelsErrorResponse (Bad Request)

        409: Conflict - ApimodelsErrorResponse (Conflict)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminCreateTag.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminCreateTag)
async def admin_create_tag_async(
    body: ApimodelsCreateTagReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """To create a tag (AdminCreateTag)

    This endpoint will create a new tag.
    The tag name must be unique per namespace.
    It is safe to call this endpoint even if the tag already exists.

    Permission: ADMIN:NAMESPACE:{namespace}:INVENTORY:TAG [CREATE]

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/tags

        method: POST

        tags: ["Admin Tags"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelsCreateTagReq in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApimodelsCreateTagResp (Created)

        400: Bad Request - ApimodelsErrorResponse (Bad Request)

        409: Conflict - ApimodelsErrorResponse (Conflict)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminCreateTag.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDeleteTag)
def admin_delete_tag(
    tag_name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """To delete a tag (AdminDeleteTag)

    This endpoint will delete a tag by tagName in a specified namespace.
    If the tagName doesn't exist in a namespace, it'll return not found.

    Permission: ADMIN:NAMESPACE:{namespace}:INVENTORY:TAG [DELETE]

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/tags/{tagName}

        method: DELETE

        tags: ["Admin Tags"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        tag_name: (tagName) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        404: Not Found - ApimodelsErrorResponse (Not Found)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminDeleteTag.create(
        tag_name=tag_name,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteTag)
async def admin_delete_tag_async(
    tag_name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """To delete a tag (AdminDeleteTag)

    This endpoint will delete a tag by tagName in a specified namespace.
    If the tagName doesn't exist in a namespace, it'll return not found.

    Permission: ADMIN:NAMESPACE:{namespace}:INVENTORY:TAG [DELETE]

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/tags/{tagName}

        method: DELETE

        tags: ["Admin Tags"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        tag_name: (tagName) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        404: Not Found - ApimodelsErrorResponse (Not Found)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminDeleteTag.create(
        tag_name=tag_name,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminListTags)
def admin_list_tags(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    owner: Optional[str] = None,
    sort_by: Optional[Union[str, AdminListTagsSortByEnum]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """To list tags (AdminListTags)

    This endpoint will list all tags in a namespace.
    The response body will be in the form of standard pagination.

    Permission: ADMIN:NAMESPACE:{namespace}:INVENTORY:TAG [READ]

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/tags

        method: GET

        tags: ["Admin Tags"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        owner: (owner) OPTIONAL str in query

        sort_by: (sortBy) OPTIONAL Union[str, SortByEnum] in query

    Responses:
        200: OK - ApimodelsListTagsResp (OK)

        400: Bad Request - ApimodelsErrorResponse (Bad Request)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListTags.create(
        limit=limit,
        offset=offset,
        owner=owner,
        sort_by=sort_by,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminListTags)
async def admin_list_tags_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    owner: Optional[str] = None,
    sort_by: Optional[Union[str, AdminListTagsSortByEnum]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """To list tags (AdminListTags)

    This endpoint will list all tags in a namespace.
    The response body will be in the form of standard pagination.

    Permission: ADMIN:NAMESPACE:{namespace}:INVENTORY:TAG [READ]

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/tags

        method: GET

        tags: ["Admin Tags"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        owner: (owner) OPTIONAL str in query

        sort_by: (sortBy) OPTIONAL Union[str, SortByEnum] in query

    Responses:
        200: OK - ApimodelsListTagsResp (OK)

        400: Bad Request - ApimodelsErrorResponse (Bad Request)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListTags.create(
        limit=limit,
        offset=offset,
        owner=owner,
        sort_by=sort_by,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Inventory Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model
from accelbyte_py_sdk.core import ApiError

from ..models.apimodels_error_response import ApimodelsErrorResponse


class ApimodelsChainingOperationResp(Model):
    """Apimodels chaining operation resp (apimodels.ChainingOperationResp)

    Properties:
        message: (message) REQUIRED str

        error_details: (errorDetails) OPTIONAL ApimodelsErrorResponse

        replayed: (replayed) OPTIONAL bool

        request_id: (requestId) OPTIONAL str
    """

    # region fields

    message: str  # REQUIRED
    error_details: ApimodelsErrorResponse  # OPTIONAL
    replayed: bool  # OPTIONAL
    request_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_message(self, value: str) -> ApimodelsChainingOperationResp:
        self.message = value
        return self

    def with_error_details(
        self, value: ApimodelsErrorResponse
    ) -> ApimodelsChainingOperationResp:
        self.error_details = value
        return self

    def with_replayed(self, value: bool) -> ApimodelsChainingOperationResp:
        self.replayed = value
        return self

    def with_request_id(self, value: str) -> ApimodelsChainingOperationResp:
        self.request_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "message"):
            result["message"] = str(self.message)
        elif include_empty:
            result["message"] = ""
        if hasattr(self, "error_details"):
            result["errorDetails"] = self.error_details.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["errorDetails"] = ApimodelsErrorResponse()
        if hasattr(self, "replayed"):
            result["replayed"] = bool(self.replayed)
        elif include_empty:
            result["replayed"] = False
        if hasattr(self, "request_id"):
            result["requestId"] = str(self.request_id)
        elif include_empty:
            result["requestId"] = ""
        return result

    def translate_to_api_error(self) -> ApiError:
        return ApiError(
            code=str(getattr(self, "error_details", "")) or "",
            message=str(getattr(self, "message", "")) or "",
        )

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        message: str,
        error_details: Optional[ApimodelsErrorResponse] = None,
        replayed: Optional[bool] = None,
        request_id: Optional[str] = None,
        **kwargs,
    ) -> ApimodelsChainingOperationResp:
        instance = cls()
        instance.message = message
        if error_details is not None:
            instance.error_details = error_details
        if replayed is not None:
            instance.replayed = replayed
        if request_id is not None:
            instance.request_id = request_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsChainingOperationResp:
        instance = cls()
        if not dict_:
            return instance
        if "message" in dict_ and dict_["message"] is not None:
            instance.message = str(dict_["message"])
        elif include_empty:
            instance.message = ""
        if "errorDetails" in dict_ and dict_["errorDetails"] is not None:
            instance.error_details = ApimodelsErrorResponse.create_from_dict(
                dict_["errorDetails"], include_empty=include_empty
            )
        elif include_empty:
            instance.error_details = ApimodelsErrorResponse()
        if "replayed" in dict_ and dict_["replayed"] is not None:
            instance.replayed = bool(dict_["replayed"])
        elif include_empty:
            instance.replayed = False
        if "requestId" in dict_ and dict_["requestId"] is not None:
            instance.request_id = str(dict_["requestId"])
        elif include_empty:
            instance.request_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsChainingOperationResp]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsChainingOperationResp]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsChainingOperationResp,
        List[ApimodelsChainingOperationResp],
        Dict[Any, ApimodelsChainingOperationResp],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "message": "message",
            "errorDetails": "error_details",
            "replayed": "replayed",
            "requestId": "request_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "message": True,
            "errorDetails": False,
            "replayed": False,
            "requestId": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ApimodelsChainingOperationReq
from ..models import ApimodelsChainingOperationResp

from ..operations.admin_chaining_operations import AdminCreateChainingOperations


@same_doc_as(AdminCreateChainingOperations)
def admin_create_chaining_operations(
    body: ApimodelsChainingOperationReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """To Create Chaining Operation (AdminCreateChainingOperations)

    Create chaining Operations.
    This process will run sequentially
    1. remove item process
    2. consume item process
    3. update item process
    4. create item process
    if toSpecificInventory set as true, then inventoryId field will be mandatory, vice versa

    The behavior of each process is same with current admin level endpoint

    requestId: Request id(Optional), client should provide a unique request id to perform at most once execution, When a request id is resubmitted,
    it will return original successful response
    replayed : replayed, if true,the response is original successful response. This will not be included in response if client have not pass request id.

    Permission: ADMIN:NAMESPACE:{namespace}:USER:{userId}:INVENTORY:ITEM [CREATE]

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/chainingOperations

        method: POST

        tags: ["Admin Chaining Operations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelsChainingOperationReq in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsChainingOperationResp (OK)

        400: Bad Request - ApimodelsChainingOperationResp (Bad Request)

        401: Unauthorized - ApimodelsChainingOperationResp (Unauthorized)

        403: Forbidden - ApimodelsChainingOperationResp (Forbidden)

        404: Not Found - ApimodelsChainingOperationResp (Not Found)

        500: Internal Server Error - ApimodelsChainingOperationResp (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminCreateChainingOperations.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminCreateChainingOperations)
async def admin_create_chaining_operations_async(
    body: ApimodelsChainingOperationReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """To Create Chaining Operation (AdminCreateChainingOperations)

    Create chaining Operations.
    This process will run sequentially
    1. remove item process
    2. consume item process
    3. update item process
    4. create item process
    if toSpecificInventory set as true, then inventoryId field will be mandatory, vice versa

    The behavior of each process is same with current admin level endpoint

    requestId: Request id(Optional), client should provide a unique request id to perform at most once execution, When a request id is resubmitted,
    it will return original successful response
    replayed : replayed, if true,the response is original successful response. This will not be included in response if client have not pass request id.

    Permission: ADMIN:NAMESPACE:{namespace}:USER:{userId}:INVENTORY:ITEM [CREATE]

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/chainingOperations

        method: POST

        tags: ["Admin Chaining Operations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelsChainingOperationReq in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsChainingOperationResp (OK)

        400: Bad Request - ApimodelsChainingOperationResp (Bad Request)

        401: Unauthorized - ApimodelsChainingOperationResp (Unauthorized)

        403: Forbidden - ApimodelsChainingOperationResp (Forbidden)

        404: Not Found - ApimodelsChainingOperationResp (Not Found)

        500: Internal Server Error - ApimodelsChainingOperationResp (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminCreateChainingOperations.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Inventory Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.apimodels_trade_item_resp import ApimodelsTradeItemResp


class ApimodelsMoveItemsResp(Model):
    """Apimodels move items resp (apimodels.MoveItemsResp)

    Properties:
        created_at: (createdAt) REQUIRED str

        dst_inventory_id: (dstInventoryId) REQUIRED str

        items: (items) REQUIRED List[ApimodelsTradeItemResp]

        namespace: (namespace) REQUIRED str

        src_inventory_id: (srcInventoryId) REQUIRED str
    """

    # region fields

    created_at: str  # REQUIRED
    dst_inventory_id: str  # REQUIRED
    items: List[ApimodelsTradeItemResp]  # REQUIRED
    namespace: str  # REQUIRED
    src_inventory_id: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: str) -> ApimodelsMoveItemsResp:
        self.created_at = value
        return self

    def with_dst_inventory_id(self, value: str) -> ApimodelsMoveItemsResp:
        self.dst_inventory_id = value
        return self

    def with_items(self, value: List[ApimodelsTradeItemResp]) -> ApimodelsMoveItemsResp:
        self.items = value
        return self

    def with_namespace(self, value: str) -> ApimodelsMoveItemsResp:
        self.namespace = value
        return self

    def with_src_inventory_id(self, value: str) -> ApimodelsMoveItemsResp:
        self.src_inventory_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "dst_inventory_id"):
            result["dstInventoryId"] = str(self.dst_inventory_id)
        elif include_empty:
            result["dstInventoryId"] = ""
        if hasattr(self, "items"):
            result["items"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.items
            ]
        elif include_empty:
            result["items"] = []
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "src_inventory_id"):
            result["srcInventoryId"] = str(self.src_inventory_id)
        elif include_empty:
            result["srcInventoryId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: str,
        dst_inventory_id: str,
        items: List[ApimodelsTradeItemResp],
        namespace: str,
        src_inventory_id: str,
        **kwargs,
    ) -> ApimodelsMoveItemsResp:
        instance = cls()
        instance.created_at = created_at
        instance.dst_inventory_id = dst_inventory_id
        instance.items = items
        instance.namespace = namespace
        instance.src_inventory_id = src_inventory_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsMoveItemsResp:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "dstInventoryId" in dict_ and dict_["dstInventoryId"] is not None:
            instance.dst_inventory_id = str(dict_["dstInventoryId"])
        elif include_empty:
            instance.dst_inventory_id = ""
        if "items" in dict_ and dict_["items"] is not None:
            instance.items = [
                ApimodelsTradeItemResp.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["items"]
            ]
        elif include_empty:
            instance.items = []
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "srcInventoryId" in dict_ and dict_["srcInventoryId"] is not None:
            instance.src_inventory_id = str(dict_["srcInventoryId"])
        elif include_empty:
            instance.src_inventory_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsMoveItemsResp]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsMoveItemsResp]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsMoveItemsResp,
        List[ApimodelsMoveItemsResp],
        Dict[Any, ApimodelsMoveItemsResp],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "dstInventoryId": "dst_inventory_id",
            "items": "items",
            "namespace": "namespace",
            "srcInventoryId": "src_inventory_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": True,
            "dstInventoryId": True,
            "items": True,
            "namespace": True,
            "srcInventoryId": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.2.15"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .public_bulk_remove_my_items import PublicBulkRemoveMyItems
from .public_bulk_update_my_items import PublicBulkUpdateMyItems
from .public_consume_my_item import PublicConsumeMyItem
from .public_get_item import PublicGetItem
from .public_list_items import PublicListItems
from .public_list_items import (
    SortByEnum as PublicListItemsSortByEnum,
)
from .public_move_my_items import PublicMoveMyItems



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.2.15"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .apimodels_admin_update_item_req import ApimodelsAdminUpdateItemReq
from .apimodels_bulk_save_item_error import ApimodelsBulkSaveItemError
from .apimodels_bulk_save_item_resp import ApimodelsBulkSaveItemResp
from .apimodels_chaining_operation_req import ApimodelsChainingOperationReq
from .apimodels_chaining_operation_resp import ApimodelsChainingOperationResp
from .apimodels_consume_item import ApimodelsConsumeItem
from .apimodels_consume_item_req import ApimodelsConsumeItemReq
from .apimodels_create_integration_configuration_req import (
    ApimodelsCreateIntegrationConfigurationReq,
)
from .apimodels_create_inventory_configuration_req import (
    ApimodelsCreateInventoryConfigurationReq,
)
from .apimodels_create_inventory_req import ApimodelsCreateInventoryReq
from .apimodels_create_item import ApimodelsCreateItem
from .apimodels_create_item import SourceEnum as ApimodelsCreateItemSourceEnum
from .apimodels_create_item_type_req import ApimodelsCreateItemTypeReq
from .apimodels_create_item_type_resp import ApimodelsCreateItemTypeResp
from .apimodels_create_tag_req import ApimodelsCreateTagReq
from .apimodels_create_tag_req import OwnerEnum as ApimodelsCreateTagReqOwnerEnum
from .apimodels_create_tag_resp import ApimodelsCreateTagResp
from .apimodels_create_tag_resp import OwnerEnum as ApimodelsCreateTagRespOwnerEnum
from .apimodels_delete_inventory_req import ApimodelsDeleteInventoryReq
from .apimodels_error_response import ApimodelsErrorResponse
from .apimodels_integration_configuration_resp import (
    ApimodelsIntegrationConfigurationResp,
)
from .apimodels_inventory_config import ApimodelsInventoryConfig
from .apimodels_inventory_configuration_req import ApimodelsInventoryConfigurationReq
from .apimodels_inventory_configuration_resp import ApimodelsInventoryConfigurationResp
from .apimodels_inventory_configuration_resp import (
    StatusEnum as ApimodelsInventoryConfigurationRespStatusEnum,
)
from .apimodels_inventory_resp import ApimodelsInventoryResp
from .apimodels_item_resp import ApimodelsItemResp
from .apimodels_list_integration_configurations_resp import (
    ApimodelsListIntegrationConfigurationsResp,
)
from .apimodels_list_inventory_configurations_resp import (
    ApimodelsListInventoryConfigurationsResp,
)
from .apimodels_list_inventory_resp import ApimodelsListInventoryResp
from .apimodels_list_item_resp import ApimodelsListItemResp
from .apimodels_list_item_types_resp import ApimodelsListItemTypesResp
from .apimodels_list_tags_resp import ApimodelsListTagsResp
from .apimodels_move_items_req import ApimodelsMoveItemsReq
from .apimodels_move_items_resp import ApimodelsMoveItemsResp
from .apimodels_operation import ApimodelsOperation
from .apimodels_paging import ApimodelsPaging
from .apimodels_purchase_validation_item_req import ApimodelsPurchaseValidationItemReq
from .apimodels_purchase_validation_req import ApimodelsPurchaseValidationReq
from .apimodels_remove_inventory_item_req import ApimodelsRemoveInventoryItemReq
from .apimodels_remove_item import ApimodelsRemoveItem
from .apimodels_save_item_req import ApimodelsSaveItemReq
from .apimodels_save_item_req import SourceEnum as ApimodelsSaveItemReqSourceEnum
from .apimodels_save_item_to_inventory_req import ApimodelsSaveItemToInventoryReq
from .apimodels_save_item_to_inventory_req import (
    SourceEnum as ApimodelsSaveItemToInventoryReqSourceEnum,
)
from .apimodels_trade_item import ApimodelsTradeItem
from .apimodels_trade_item_resp import ApimodelsTradeItemResp
from .apimodels_update_integration_configuration_req import (
    ApimodelsUpdateIntegrationConfigurationReq,
)
from .apimodels_update_inventory_req import ApimodelsUpdateInventoryReq
from .apimodels_update_item import ApimodelsUpdateItem
from .apimodels_update_item_req import ApimodelsUpdateItemReq
from .apimodels_update_item_resp import ApimodelsUpdateItemResp
from .apimodels_update_status_integration_configuration_req import (
    ApimodelsUpdateStatusIntegrationConfigurationReq,
)
from .apimodels_update_status_integration_configuration_req import (
    StatusEnum as ApimodelsUpdateStatusIntegrationConfigurationReqStatusEnum,
)



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.2.15"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._admin_chaining_operations import admin_create_chaining_operations
from ._admin_chaining_operations import admin_create_chaining_operations_async

from ._admin_integration_configurations import admin_create_integration_configuration
from ._admin_integration_configurations import (
    admin_create_integration_configuration_async,
)
from ._admin_integration_configurations import admin_list_integration_configurations
from ._admin_integration_configurations import (
    admin_list_integration_configurations_async,
)
from ._admin_integration_configurations import admin_update_integration_configuration
from ._admin_integration_configurations import (
    admin_update_integration_configuration_async,
)
from ._admin_integration_configurations import (
    admin_update_status_integration_configuration,
)
from ._admin_integration_configurations import (
    admin_update_status_integration_configuration_async,
)

from ._admin_inventories import admin_create_inventory
from ._admin_inventories import admin_create_inventory_async
from ._admin_inventories import admin_get_inventory
from ._admin_inventories import admin_get_inventory_async
from ._admin_inventories import admin_list_inventories
from ._admin_inventories import admin_list_inventories_async
from ._admin_inventories import admin_purchasable
from ._admin_inventories import admin_purchasable_async
from ._admin_inventories import admin_update_inventory
from ._admin_inventories import admin_update_inventory_async
from ._admin_inventories import admin_update_user_inventories_by_inventory_code
from ._admin_inventories import admin_update_user_inventories_by_inventory_code_async
from ._admin_inventories import delete_inventory
from ._admin_inventories import delete_inventory_async

from ._admin_inventory_configurations import admin_create_inventory_configuration
from ._admin_inventory_configurations import admin_create_inventory_configuration_async
from ._admin_inventory_configurations import admin_delete_inventory_configuration
from ._admin_inventory_configurations import admin_delete_inventory_configuration_async
from ._admin_inventory_configurations import admin_get_inventory_configuration
from ._admin_inventory_configurations import admin_get_inventory_configuration_async
from ._admin_inventory_configurations import admin_list_inventory_configurations
from ._admin_inventory_configurations import admin_list_inventory_configurations_async
from ._admin_inventory_configurations import admin_update_inventory_configuration
from ._admin_inventory_configurations import admin_update_inventory_configuration_async

from ._admin_item_types import admin_create_item_type
from ._admin_item_types import admin_create_item_type_async
from ._admin_item_types import admin_delete_item_type
from ._admin_item_types import admin_delete_item_type_async
from ._admin_item_types import admin_list_item_types
from ._admin_item_types import admin_list_item_types_async

from ._admin_items import admin_bulk_remove_items
from ._admin_items import admin_bulk_remove_items_async
from ._admin_items import admin_bulk_save_item
from ._admin_items import admin_bulk_save_item_async
from ._admin_items import admin_bulk_save_item_to_inventory
from ._admin_items import admin_bulk_save_item_to_inventory_async
from ._admin_items import admin_bulk_update_my_items
from ._admin_items import admin_bulk_update_my_items_async
from ._admin_items import admin_consume_user_item
from ._admin_items import admin_consume_user_item_async
from ._admin_items import admin_get_inventory_item
from ._admin_items import admin_get_inventory_item_async
from ._admin_items import admin_list_items
from ._admin_items import admin_list_items_async
from ._admin_items import admin_save_item
from ._admin_items import admin_save_item_async
from ._admin_items import admin_save_item_to_inventory
from ._admin_items import admin_save_item_to_inventory_async
from ._admin_items import admin_sync_user_entitlements
from ._admin_items import admin_sync_user_entitlements_async

from ._admin_tags import admin_create_tag
from ._admin_tags import admin_create_tag_async
from ._admin_tags import admin_delete_tag
from ._admin_tags import admin_delete_tag_async
from ._admin_tags import admin_list_tags
from ._admin_tags import admin_list_tags_async

from ._public_inventories import public_list_inventories
from ._public_inventories import public_list_inventories_async

from ._public_inventory_configurations import public_list_inventory_configurations
from ._public_inventory_configurations import public_list_inventory_configurations_async

from ._public_item_types import public_list_item_types
from ._public_item_types import public_list_item_types_async

from ._public_items import public_bulk_remove_my_items
from ._public_items import public_bulk_remove_my_items_async
from ._public_items import public_bulk_update_my_items
from ._public_items import public_bulk_update_my_items_async
from ._public_items import public_consume_my_item
from ._public_items import public_consume_my_item_async
from ._public_items import public_get_item
from ._public_items import public_get_item_async
from ._public_items import public_list_items
from ._public_items import public_list_items_async
from ._public_items import public_move_my_items
from ._public_items import public_move_my_items_async

from ._public_tags import public_list_tags
from ._public_tags import public_list_tags_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Inventory Service

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import ApiError, ApiResponse
from accelbyte_py_sdk.core import Operation
from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import HttpResponse
from accelbyte_py_sdk.core import deprecated

from ...models import ApimodelsBulkSaveItemResp
from ...models import ApimodelsErrorResponse
from ...models import ApimodelsSaveItemReq


class AdminBulkSaveItem(Operation):
    """Bulk save items to inventory (AdminBulkSaveItem)

    **This endpoint is used used for bulk saving purchased items to the playerâs inventory based on the inventoryConfigurationCode with the following conditions:**
    - If the player doesn't have the inventory for the specified inventoryConfigurationCode, a new inventory will be created for the player.
    - If the player already has one, it will be added to the existing inventory.
    >- If the same item exists within the inventory, the quantity (qty) will be increased.
    >- If the inventory is full, the item cannot be added and the request will return the âFailedâ response.
    >- If a player has more than one inventory and the initial inventory is full, the service will check the available slot in the other inventory following the order of their creation date and time (createdAt).

    - For E-commerce items:
    >- Attributes such as slotUsed, serverCustomAttributes, customAttributes, and type will be overridden by the attributes configured in the AccelByte Gaming Services (AGS) Store.
    >- Storing E-commerce items in a particular slot will follow its entitlement and item configuration, such as durable, consumable, stackable and non-stackable.
    >- The quantity is dynamically set based on an itemâs useCount configured in Store. When saving an item, the specified quantity will be multiplied by configured useCount for that particular item. For example, if an Item is configured with a useCount of 5 in the AGS Store and it is saved with a qty of 2, the itemâs quantity will be stored as 10 in the playerâs inventory.

    **When configuring your request, note the following:**
    - The source field is mandatory for determining the source of the item. The supported values are OTHER (for items coming from other sources) and E-commerce for items coming from the E-commerce integration.
    - For other-sourced items, the type can be manually defined when saving the item.
    - A maximum of 10 items can be saved in a single bulk call.

    You must have this permission to access this endpoint:
    **Permission: ADMIN:NAMESPACE:{namespace}:USER:{userId}:INVENTORY:ITEM [CREATE]**

    Properties:
        url: /inventory/v1/admin/namespaces/{namespace}/users/{userId}/items/bulk

        method: POST

        tags: ["Admin Items"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[ApimodelsSaveItemReq] in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - List[ApimodelsBulkSaveItemResp] (OK)

        400: Bad Request - ApimodelsErrorResponse (Bad Request)

        401: Unauthorized - ApimodelsErrorResponse (Unauthorized)

        403: Forbidden - ApimodelsErrorResponse (Forbidden)

        404: Not Found - ApimodelsErrorResponse (Not Found)

        422: Unprocessable Entity - ApimodelsErrorResponse (Unprocessable Entity)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)
    """

    # region fields

    _url: str = "/inventory/v1/admin/namespaces/{namespace}/users/{userId}/items/bulk"
    _path: str = "/inventory/v1/admin/namespaces/{namespace}/users/{userId}/items/bulk"
    _base_path: str = ""
    _method: str = "POST"
    _consumes: List[str] = ["application/json"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    service_name: Optional[str] = "inventory"

    body: List[ApimodelsSaveItemReq]  # REQUIRED in [body]
    namespace: str  # REQUIRED in [path]
    user_id: str  # REQUIRED in [path]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def path(self) -> str:
        return self._path

    @property
    def base_path(self) -> str:
        return self._base_path

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "body": self.get_body_params(),
            "path": self.get_path_params(),
        }

    def get_body_params(self) -> Any:
        if not hasattr(self, "body") or self.body is None:
            return None
        return [i.to_dict() for i in self.body]

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        if hasattr(self, "user_id"):
            result["userId"] = self.user_id
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_body(self, value: List[ApimodelsSaveItemReq]) -> AdminBulkSaveItem:
        self.body = value
        return self

    def with_namespace(self, value: str) -> AdminBulkSaveItem:
        self.namespace = value
        return self

    def with_user_id(self, value: str) -> AdminBulkSaveItem:
        self.user_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "body") and self.body:
            result["body"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.body
            ]
        elif include_empty:
            result["body"] = []
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "user_id") and self.user_id:
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        return result

    # endregion to methods

    # region response methods

    class Response(ApiResponse):
        data_200: Optional[List[ApimodelsBulkSaveItemResp]] = None
        error_400: Optional[ApimodelsErrorResponse] = None
        error_401: Optional[ApimodelsErrorResponse] = None
        error_403: Optional[ApimodelsErrorResponse] = None
        error_404: Optional[ApimodelsErrorResponse] = None
        error_422: Optional[ApimodelsErrorResponse] = None
        error_500: Optional[ApimodelsErrorResponse] = None

        def ok(self) -> AdminBulkSaveItem.Response:
            if self.error_400 is not None:
                err = self.error_400.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_401 is not None:
                err = self.error_401.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_403 is not None:
                err = self.error_403.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_404 is not None:
                err = self.error_404.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_422 is not None:
                err = self.error_422.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_500 is not None:
                err = self.error_500.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            return self

        def __iter__(self):
            if self.data_200 is not None:
                yield self.data_200
                yield None
            elif self.error_400 is not None:
                yield None
                yield self.error_400
            elif self.error_401 is not None:
                yield None
                yield self.error_401
            elif self.error_403 is not None:
                yield None
                yield self.error_403
            elif self.error_404 is not None:
                yield None
                yield self.error_404
            elif self.error_422 is not None:
                yield None
                yield self.error_422
            elif self.error_500 is not None:
                yield None
                yield self.error_500
            else:
                yield None
                yield self.error

    # noinspection PyMethodMayBeStatic
    def parse_response(self, code: int, content_type: str, content: Any) -> Response:
        """Parse the given response.

        200: OK - List[ApimodelsBulkSaveItemResp] (OK)

        400: Bad Request - ApimodelsErrorResponse (Bad Request)

        401: Unauthorized - ApimodelsErrorResponse (Unauthorized)

        403: Forbidden - ApimodelsErrorResponse (Forbidden)

        404: Not Found - ApimodelsErrorResponse (Not Found)

        422: Unprocessable Entity - ApimodelsErrorResponse (Unprocessable Entity)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        result = AdminBulkSaveItem.Response()

        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )

        if error is not None:
            if not error.is_no_content():
                result.error = ApiError.create_from_http_response(error)
        else:
            code, content_type, content = pre_processed_response

            if code == 200:
                result.data_200 = [
                    ApimodelsBulkSaveItemResp.create_from_dict(i) for i in content
                ]
            elif code == 400:
                result.error_400 = ApimodelsErrorResponse.create_from_dict(content)
                result.error = result.error_400.translate_to_api_error()
            elif code == 401:
                result.error_401 = ApimodelsErrorResponse.create_from_dict(content)
                result.error = result.error_401.translate_to_api_error()
            elif code == 403:
                result.error_403 = ApimodelsErrorResponse.create_from_dict(content)
                result.error = result.error_403.translate_to_api_error()
            elif code == 404:
                result.error_404 = ApimodelsErrorResponse.create_from_dict(content)
                result.error = result.error_404.translate_to_api_error()
            elif code == 422:
                result.error_422 = ApimodelsErrorResponse.create_from_dict(content)
                result.error = result.error_422.translate_to_api_error()
            elif code == 500:
                result.error_500 = ApimodelsErrorResponse.create_from_dict(content)
                result.error = result.error_500.translate_to_api_error()
            else:
                result.error = ApiError.create_from_http_response(
                    HttpResponse.create_undocumented_response(
                        code=code, content_type=content_type, content=content
                    )
                )

        result.status_code = str(code)
        result.content_type = content_type

        if 400 <= code <= 599 or result.error is not None:
            result.is_success = False

        return result

    # noinspection PyMethodMayBeStatic
    @deprecated
    def parse_response_x(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, List[ApimodelsBulkSaveItemResp]],
        Union[None, ApimodelsErrorResponse, HttpResponse],
    ]:
        """Parse the given response.

        200: OK - List[ApimodelsBulkSaveItemResp] (OK)

        400: Bad Request - ApimodelsErrorResponse (Bad Request)

        401: Unauthorized - ApimodelsErrorResponse (Unauthorized)

        403: Forbidden - ApimodelsErrorResponse (Forbidden)

        404: Not Found - ApimodelsErrorResponse (Not Found)

        422: Unprocessable Entity - ApimodelsErrorResponse (Unprocessable Entity)

        500: Internal Server Error - ApimodelsErrorResponse (Internal Server Error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return [
                ApimodelsBulkSaveItemResp.create_from_dict(i) for i in content
            ], None
        if code == 400:
            return None, ApimodelsErrorResponse.create_from_dict(content)
        if code == 401:
            return None, ApimodelsErrorResponse.create_from_dict(content)
        if code == 403:
            return None, ApimodelsErrorResponse.create_from_dict(content)
        if code == 404:
            return None, ApimodelsErrorResponse.create_from_dict(content)
        if code == 422:
            return None, ApimodelsErrorResponse.create_from_dict(content)
        if code == 500:
            return None, ApimodelsErrorResponse.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls, body: List[ApimodelsSaveItemReq], namespace: str, user_id: str, **kwargs
    ) -> AdminBulkSaveItem:
        instance = cls()
        instance.body = body
        instance.namespace = namespace
        instance.user_id = user_id
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AdminBulkSaveItem:
        instance = cls()
        if "body" in dict_ and dict_["body"] is not None:
            instance.body = [
                ApimodelsSaveItemReq.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["body"]
            ]
        elif include_empty:
            instance.body = []
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "body": "body",
            "namespace": "namespace",
            "userId": "user_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "body": True,
            "namespace": True,
            "userId": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.2.15"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_bulk_remove_items import AdminBulkRemoveItems
from .admin_bulk_save_item import AdminBulkSaveItem
from .admin_bulk_save_item_to_7fa299 import AdminBulkSaveItemToInventory
from .admin_bulk_update_my_items import AdminBulkUpdateMyItems
from .admin_consume_user_item import AdminConsumeUserItem
from .admin_get_inventory_item import AdminGetInventoryItem
from .admin_list_items import AdminListItems
from .admin_list_items import (
    SortByEnum as AdminListItemsSortByEnum,
)
from .admin_save_item import AdminSaveItem
from .admin_save_item_to_inventory import AdminSaveItemToInventory
from .admin_sync_user_entitlements import AdminSyncUserEntitlements
